#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai-app-static
version:              3.1.9.1
visibility:           public
id:                   wai-app-static-3.1.9.1-AFs5TNXOX8ADxWNylBemhs
key:                  wai-app-static-3.1.9.1-AFs5TNXOX8ADxWNylBemhs
license:              MIT
maintainer:
    Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>

author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/book/web-application-interface
synopsis:             WAI application for static serving
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-app-static>.

category:             Web, Yesod
abi:                  5bdca23bed5ef3a58778b8b75bce1f04
exposed:              True
exposed-modules:
    Network.Wai.Application.Static WaiAppStatic.CmdLine
    WaiAppStatic.Listing WaiAppStatic.Storage.Embedded
    WaiAppStatic.Storage.Filesystem WaiAppStatic.Types

hidden-modules:
    Util WaiAppStatic.Storage.Embedded.Runtime
    WaiAppStatic.Storage.Embedded.TH

import-dirs:          /usr/lib/ghc-9.6.6/site-local/wai-app-static-3.1.9.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/wai-app-static-3.1.9.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/wai-app-static-3.1.9.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-app-static
hs-libraries:         HSwai-app-static-3.1.9.1-AFs5TNXOX8ADxWNylBemhs
depends:
    base-4.18.2.1 base64-bytestring-1.2.1.0-LZzfJtlIG52AkUlWG0qoMe
    blaze-html-0.9.2.0-FHozDOQfWbTE40Bgc3es6n
    blaze-markup-0.8.3.0-H0aLsJdkrRa2dxgQ4kTQHF bytestring-0.11.5.3
    containers-0.6.7 cryptohash-md5-0.11.101.0-JKOf4PVxLvC9vNK04u1yo
    directory-1.3.8.5 file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz
    filepath-1.4.300.1 http-date-0.0.11-GGzHVleigSSF0OJS6Em1WP
    http-types-0.12.4-FjxwRmZWhoR3wzry1r4T66
    mime-types-0.1.2.1-1xtxegTvlKyFu1aTXaUpBN
    old-locale-1.0.0.7-Gunit3UBy5P9OGDVFY5MhC
    optparse-applicative-0.18.1.0-5QX38E1JQlq4e4oHsAaFH0
    template-haskell-2.20.0.0 text-2.0.2 time-1.12.2
    transformers-0.6.1.0 unix-compat-0.7.4.1-8Nyb3Roak9p6hLEN8WA8dO
    unordered-containers-0.2.21-5Z67IC6H036CG8YRUzTmvt
    wai-3.2.4-E4t208bIe9WGNSF4hxnMlb
    wai-extra-3.1.18-Fou7cm0G9MTAS8EcGO27uk
    warp-3.4.0-88S7teaxVGTKO5mHEdGrcO
    zlib-0.7.1.0-HgVwWopIY16LHV8ByRCkHf

haddock-interfaces:
    /usr/share/doc/haskell-wai-app-static/html/wai-app-static.haddock

haddock-html:         /usr/share/doc/haskell-wai-app-static/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

